@@ -42,14 +42,17 @@ int main(argc,argv)
     }
 
 
-    nsres = nis_lookup(argv[1], 0);
+    nsres = nis_lookup(argv[1], EXPAND_NAME);
     if (nsres == NULL)
     {
 	perror("nis_lookup");
 	exit(3);
     }
-	
-    nis_print_result(nsres);
+
+    if (nsres->status != 0 && nsres->status != 1)
+        nis_perror(nsres->status, argv[1]);
+    else
+        nis_print_result(nsres);
 
     nis_freeresult(nsres);
     
