@@ -50,18 +50,21 @@ extern void _endspent(void);
 extern struct spwd *_getspent(void);
 extern struct spwd *_getspnam(const char *name);
 
-extern struct spwd *sgetspent(char *buf);
+extern struct spwd *sgetspent(const char *buf);
 extern struct spwd *fgetspent(FILE *fp);
 
-extern int sputspent(struct spwd *sp, char *buf);
-extern int fputspent(struct spwd *sp, FILE *fp);
+extern int sputspent(const struct spwd *sp, char *buf);
+extern int fputspent(const struct spwd *sp, FILE *fp);
 
 extern void setspent(void);
 extern void endspent(void);
 extern struct spwd *getspent(void);
 extern struct spwd *getspnam(const char *name);
 
-/* John F. Haugh II shadow library compatibility function */
-extern int putspent(struct spwd *sp, FILE *fp);
+/* John F. Haugh II shadow library compatibility stuff */
+extern int putspent(const struct spwd *sp, FILE *fp);
+#define SHADOW _PATH_SHADOW
+
+#include <gshadow.h>
 
 #endif
