@@ -30,32 +30,31 @@
 #include "dns_ethers.h"
 
 
-void dns_setethent(void *opts)
+void dns_setethent(void)
 {
 }
 
 
-void dns_endethent(void *opts)
+void dns_endethent(void)
 {
 }
 
 
-struct ether *dns_getethent(void *opts)
+struct ether *dns_getethent(void)
 {
     errno = ECONNREFUSED;
     return NULL;
 }
 
 
-struct ether *dns_getethbyname(char *name,
-			      void *opts)
+struct ether *dns_getethbyname(const char *name)
 {
     errno = ECONNREFUSED;
     return NULL;
 }
 
 
-struct ether *dns_getethbyaddr(struct ether_addr *addr, void *opts)
+struct ether *dns_getethbyaddr(const struct ether_addr *addr)
 {
     errno = ECONNREFUSED;
     return NULL;
