@@ -29,11 +29,10 @@
 #include <sys/types.h>
 #include <netdb.h>
 
-extern void dns_setnetent(int stayopen, void *opts);
-extern void dns_endnetent(void *opts);
-extern struct netent *dns_getnetent(void *opts);
-extern struct netent *dns_getnetbyname(const char *name, void *opts);
-extern struct netent *dns_getnetbyaddr(long net, int type,
-				       void *opts);
+extern void dns_setnetent(int stayopen);
+extern void dns_endnetent(void);
+extern struct netent *dns_getnetent(void);
+extern struct netent *dns_getnetbyname(const char *name);
+extern struct netent *dns_getnetbyaddr(long net, int type);
 
 #endif
