@@ -30,32 +30,31 @@
 #include "dns_protocols.h"
 
 
-void dns_setprotoent(int stayopen, void *opts)
+void dns_setprotoent(int stayopen)
 {
 }
 
 
-void dns_endprotoent(void *opts)
+void dns_endprotoent(void)
 {
 }
 
 
-struct protoent *dns_getprotoent(void *opts)
+struct protoent *dns_getprotoent(void)
 {
     errno = ECONNREFUSED;
     return NULL;
 }
 
 
-struct protoent *dns_getprotobyname(const char *name,
-				    void *opts)
+struct protoent *dns_getprotobyname(const char *name)
 {
     errno = ECONNREFUSED;
     return NULL;
 }
 
 
-struct protoent *dns_getprotobynumber(int number, void *opts)
+struct protoent *dns_getprotobynumber(int number)
 {
     errno = ECONNREFUSED;
     return NULL;
