@@ -30,32 +30,31 @@
 #include "dns_rpc.h"
 
 
-void dns_setrpcent(int stayopen, void *opts)
+void dns_setrpcent(int stayopen)
 {
 }
 
 
-void dns_endrpcent(void *opts)
+void dns_endrpcent(void)
 {
 }
 
 
-struct rpcent *dns_getrpcent(void *opts)
+struct rpcent *dns_getrpcent(void)
 {
     errno = ECONNREFUSED;
     return NULL;
 }
 
 
-struct rpcent *dns_getrpcbyname(const char *name,
-				void *opts)
+struct rpcent *dns_getrpcbyname(const char *name)
 {
     errno = ECONNREFUSED;
     return NULL;
 }
 
 
-struct rpcent *dns_getrpcbynumber(int number, void *opts)
+struct rpcent *dns_getrpcbynumber(int number)
 {
     errno = ECONNREFUSED;
     return NULL;
