@@ -26,6 +26,7 @@
 #include <string.h>
 #include <grp.h>
 #include "misc.h"
+#include "xalloc.h"
 
 #ifndef _PATH_GROUP
 #define _PATH_GROUP "/etc/group"
@@ -87,42 +88,46 @@ static int add_member(struct group *grp, char *name)
 }
 
 
-struct group *sgetgrent(char *buf)
+struct group *sgetgrent(const char *str)
 {
     static struct group grp;
+    static char *buf = NULL;
     char *cp, *sp;
 
 
-    sp = buf;
-    cp = strchr(sp, ':');
-    if (cp == NULL)
+    if (Xalloc(&buf, strlen(str)+1) == NULL)
 	return NULL;
-    if (*cp)
-	*cp++ = '\0';
-    grp.gr_name = sp;
+    strcpy(buf, str);
 
     sp = buf;
     cp = strchr(sp, ':');
     if (cp == NULL)
 	return NULL;
-    if (*cp)
-	*cp++ = '\0';
+
+    *cp++ = '\0';
+    grp.gr_name = sp;
+
+    
+    sp = cp;
+    cp = strchr(sp, ':');
+    if (cp == NULL)
+	return NULL;
+
+    *cp++ = '\0';
     grp.gr_passwd = sp;
 
 
-    sp = buf;
+    sp = cp;
     cp = strchr(sp, ':');
     if (cp == NULL)
 	return NULL;
-    if (*cp)
-	*cp++ = '\0';
+    *cp++ = '\0';
     if (*sp)
 	grp.gr_gid = atoi(sp);
     else
 	grp.gr_gid = -1;
 
     sp = cp;
-    
     if (grp.gr_mem)
     {
 	free(grp.gr_mem);
