@@ -27,10 +27,10 @@
 #include <sys/types.h>
 #include <ethers.h>
 
-void nis_setethent(void *opts);
-void nis_endethent(void *opts);
-struct ether * nis_getethent(void *opts);
-struct ether * nis_getethbyname(char *name, void *opts);
-struct ether * nis_getethbyaddr(struct ether_addr *addr, void *opts);
+extern void nis_setethent(void);
+extern void nis_endethent(void);
+extern struct ether * nis_getethent(void);
+extern struct ether * nis_getethbyname(const char *name);
+extern struct ether * nis_getethbyaddr(const struct ether_addr *addr);
 
 #endif
