@@ -33,31 +33,31 @@
 #include "nis_group.h"
 
 
-void nis_setgrent(void *opts)
+void nis_setgrent(void)
 {
 }
 
 
-void nis_endgrent(void *opts)
+void nis_endgrent(void)
 {
 }
 
 
-struct group *nis_getgrent(void *opts)
+struct group *nis_getgrent(void)
 {
     errno = ECONNREFUSED;
     return NULL;
 }
 
 
-struct group *nis_getgrgid(gid_t gid, void *opts)
+struct group *nis_getgrgid(gid_t gid)
 {
     errno = ECONNREFUSED;
     return NULL;
 }
 
 
-struct group *nis_getgrnam(const char *name, void *opts)
+struct group *nis_getgrnam(const char *name)
 {
     errno = ECONNREFUSED;
     return NULL;
