@@ -29,11 +29,10 @@
 #include <sys/types.h>
 #include <netdb.h>
 
-extern void nis_setnetent(int stayopen, void *opts);
-extern void nis_endnetent(void *opts);
-extern struct netent *nis_getnetent(void *opts);
-extern struct netent *nis_getnetbyname(const char *name, void *opts);
-extern struct netent *nis_getnetbyaddr(long net, int type,
-				       void *opts);
+extern void nis_setnetent(int stayopen);
+extern void nis_endnetent(void);
+extern struct netent *nis_getnetent(void);
+extern struct netent *nis_getnetbyname(const char *name);
+extern struct netent *nis_getnetbyaddr(long net, int type);
 
 #endif
