@@ -29,15 +29,10 @@
 #include <sys/types.h>
 #include <netdb.h>
 
-extern void nis_setprotoent(int stayopen, void *opts);
-extern void nis_endprotoent(void *opts);
-extern struct protoent *nis_getprotoent(void *opts);
-extern struct protoent *nis_getprotobyname(const char *name,
-					   void *opts);
-extern struct protoent *nis_getprotobynumber(int number,
-					     void *opts);
+extern void nis_setprotoent(int stayopen);
+extern void nis_endprotoent(void);
+extern struct protoent *nis_getprotoent(void);
+extern struct protoent *nis_getprotobyname(const char *name);
+extern struct protoent *nis_getprotobynumber(int number);
 
 #endif
-
-
-
