@@ -30,32 +30,31 @@
 #include "nis_rpc.h"
 
 
-void nis_setrpcent(int stayopen, void *opts)
+void nis_setrpcent(int stayopen)
 {
 }
 
 
-void nis_endrpcent(void *opts)
+void nis_endrpcent(void)
 {
 }
 
 
-struct rpcent *nis_getrpcent(void *opts)
+struct rpcent *nis_getrpcent(void)
 {
     errno = ECONNREFUSED;
     return NULL;
 }
 
 
-struct rpcent *nis_getrpcbyname(const char *name,
-				void *opts)
+struct rpcent *nis_getrpcbyname(const char *name)
 {
     errno = ECONNREFUSED;
     return NULL;
 }
 
 
-struct rpcent *nis_getrpcbynumber(int number, void *opts)
+struct rpcent *nis_getrpcbynumber(int number)
 {
     errno = ECONNREFUSED;
     return NULL;
