@@ -29,15 +29,10 @@
 #include <sys/types.h>
 #include <netdb.h>
 
-extern void nis_setrpcent(int stayopen, void *opts);
-extern void nis_endrpcent(void *opts);
-extern struct rpcent *nis_getrpcent(void *opts);
-extern struct rpcent *nis_getrpcbyname(const char *name,
-				       void *opts);
-extern struct rpcent *nis_getrpcbynumber(int number,
-					 void *opts);
+extern void nis_setrpcent(int stayopen);
+extern void nis_endrpcent(void);
+extern struct rpcent *nis_getrpcent(void);
+extern struct rpcent *nis_getrpcbyname(const char *name);
+extern struct rpcent *nis_getrpcbynumber(int number);
 
 #endif
-
-
-
