@@ -33,24 +33,24 @@
 #include "nis_shadow.h"
 
 
-void nis_setspent(void *opts)
+void nis_setspent(void)
 {
 }
 
 
-void nis_endspent(void *opts)
+void nis_endspent(void)
 {
 }
 
 
-struct spwd *nis_getspent(void *opts)
+struct spwd *nis_getspent(void)
 {
     errno = ECONNREFUSED;
     return NULL;
 }
 
 
-struct spwd *nis_getspnam(const char *name, void *opts)
+struct spwd *nis_getspnam(const char *name)
 {
     errno = ECONNREFUSED;
     return NULL;
