@@ -40,10 +40,10 @@
 #include "../dns/dns_ethers.h"
 #endif
 
-void _ENSWF(_setethent)(void);
-void _ENSWF(_endethent)(void);
-struct ether * _ENSWF(_getethent)(void);
-struct ether * _ENSWF(_getethbyname)(char *name);
-struct ether * _ENSWF(_getethbyaddr)(struct ether_addr *addr);
+extern void _ENSWF(_setethent)(void);
+extern void _ENSWF(_endethent)(void);
+extern struct ether * _ENSWF(_getethent)(void);
+extern struct ether * _ENSWF(_getethbyname)(const char *name);
+extern struct ether * _ENSWF(_getethbyaddr)(const struct ether_addr *addr);
 
 #endif
