@@ -42,7 +42,7 @@
 void _ENSWF(_setrpcent)(int stayopen);
 void _ENSWF(_endrpcent)(void);
 struct rpcent * _ENSWF(_getrpcent)(void);
-struct rpcent * _ENSWF(_getrpcbyname)(char *name);
+struct rpcent * _ENSWF(_getrpcbyname)(const char *name);
 struct rpcent * _ENSWF(_getrpcbynumber)(int number);
 
 #endif
