@@ -27,10 +27,10 @@
 #include <sys/types.h>
 #include <ethers.h>
 
-void yp_setethent(void *opts);
-void yp_endethent(void *opts);
-struct ether * yp_getethent(void *opts);
-struct ether * yp_getethbyname(char *name, void *opts);
-struct ether * yp_getethbyaddr(struct ether_addr *addr, void *opts);
+extern void yp_setethent(void);
+extern void yp_endethent(void);
+extern struct ether * yp_getethent(void);
+extern struct ether * yp_getethbyname(const char *name);
+extern struct ether * yp_getethbyaddr(const struct ether_addr *addr);
 
 #endif
