@@ -103,7 +103,7 @@ static struct netent *netent_parse(char *str, int len)
 
 
 
-void yp_setnetent(int stayopen, void *opts)
+void yp_setnetent(int stayopen)
 {
     rewind_flag = 1;
     if (savekey)
@@ -111,7 +111,7 @@ void yp_setnetent(int stayopen, void *opts)
 }
 
 
-void yp_endnetent(void *opts)
+void yp_endnetent(void)
 {
     rewind_flag = 1;
     if (savekey)
@@ -119,7 +119,7 @@ void yp_endnetent(void *opts)
 }
 
 
-struct netent *yp_getnetent(void *opts)
+struct netent *yp_getnetent(void)
 {
     struct netent *net;
     char *map;
@@ -130,7 +130,7 @@ struct netent *yp_getnetent(void *opts)
     int keylen;
 
 
-    map = _ypopts_getmd(opts, "networks", ".byaddr", &domain);
+    map = _ypopts_getmd("networks", ".byaddr", &domain);
     if (map == NULL)
 	return NULL;
 
@@ -170,7 +170,7 @@ struct netent *yp_getnetent(void *opts)
 }
 
 
-struct netent *yp_getnetbyaddr(long net, int type, void *opts)
+struct netent *yp_getnetbyaddr(long net, int type)
 {
     struct netent *nep;
     char *map;
@@ -182,7 +182,7 @@ struct netent *yp_getnetbyaddr(long net, int type, void *opts)
     struct in_addr in;
     
 
-    map = _ypopts_getmd(opts, "networks", ".byaddr", &domain);
+    map = _ypopts_getmd("networks", ".byaddr", &domain);
     if (map == NULL)
 	return NULL;
 
@@ -213,7 +213,7 @@ struct netent *yp_getnetbyaddr(long net, int type, void *opts)
 }
 
 
-struct netent *yp_getnetbyname(const char *name, void *opts)
+struct netent *yp_getnetbyname(const char *name)
 {
     struct netent *net;
     char *map;
@@ -221,7 +221,7 @@ struct netent *yp_getnetbyname(const char *name, void *opts)
     char *result;
     int len;
 
-    map = _ypopts_getmd(opts, "networks", ".byname", &domain);
+    map = _ypopts_getmd("networks", ".byname", &domain);
     if (map == NULL)
 	return NULL;
 
