@@ -30,10 +30,10 @@
 #include <sys/types.h>
 #include <netdb.h>
 
-extern void yp_setnetent(int stayopen, void *opts);
-extern void yp_endnetent(void *opts);
-extern struct netent *yp_getnetent(void *opts);
-extern struct netent *yp_getnetbyaddr(long net, int type, void *opts);
-extern struct netent *yp_getnetbyname(const char *name, void *opts);
+extern void yp_setnetent(int stayopen);
+extern void yp_endnetent(void);
+extern struct netent *yp_getnetent(void);
+extern struct netent *yp_getnetbyaddr(long net, int type);
+extern struct netent *yp_getnetbyname(const char *name);
 
 #endif
