@@ -29,11 +29,11 @@
 #include <sys/types.h>
 #include <pwd.h>
 
-extern void yp_setpwent(void *opts);
-extern void yp_endpwent(void *opts);
-extern struct passwd *yp_getpwent(void *opts);
-extern struct passwd *yp_getpwuid(uid_t uid, void *opts);
-extern struct passwd *yp_getpwnam(const char *name, void *opts);
+extern void yp_setpwent(void);
+extern void yp_endpwent(void);
+extern struct passwd *yp_getpwent(void);
+extern struct passwd *yp_getpwuid(uid_t uid);
+extern struct passwd *yp_getpwnam(const char *name);
 
 #endif
 
