@@ -92,14 +92,14 @@ static struct servent *servent_parse(char *str, int len)
     return &sb;
 }
 
-void yp_setservent(int stayopen, void *opts)
+void yp_setservent(int stayopen)
 {
     rewind_flag = 1;
     if (savekey)
 	free(savekey);
 }
 
-void yp_endservent(void *opts)
+void yp_endservent(void)
 {
     rewind_flag = 1;
     if (savekey)
@@ -107,7 +107,7 @@ void yp_endservent(void *opts)
 }
 
 
-struct servent *yp_getservent(void *opts)
+struct servent *yp_getservent(void)
 {
     struct servent *sp;
     char *map;
@@ -118,7 +118,7 @@ struct servent *yp_getservent(void *opts)
     int keylen;
 
 
-    map = _ypopts_getmd(opts, "services", ".byname", &domain);
+    map = _ypopts_getmd("services", ".byname", &domain);
     if (map == NULL)
 	return NULL;
 
@@ -188,27 +188,25 @@ struct servent *yp_getservent(void *opts)
 ** This is *not* an efficient way to do it...
 */
 struct servent *yp_getservbyname(const char *name,
-				 const char *protocol,
-				 void *opts)
+				 const char *protocol)
 {
     struct servent *sp;
 
     
-    yp_setservent(0, opts);
+    yp_setservent(0);
 
-    while ((sp = yp_getservent(opts)) &&
+    while ((sp = yp_getservent()) &&
 	   strcmp(sp->s_name, name) &&
 	   strcmp(sp->s_proto, protocol))
 	;
 
-    yp_endservent(opts);
+    yp_endservent();
     return sp;
 }
 
 
 struct servent *yp_getservbyport(int port,
-				 const char *protocol,
-				 void *opts)
+				 const char *protocol)
 {
     struct servent *sp;
     char buf[256];
@@ -218,7 +216,7 @@ struct servent *yp_getservbyport(int port,
     int len;
 
 
-    map = _ypopts_getmd(opts, "services", ".byname", &domain);
+    map = _ypopts_getmd("services", ".byname", &domain);
     if (map == NULL)
 	return NULL;
 
