@@ -25,8 +25,7 @@
 
 #include <stdio.h>
 #include <stdlib.h>
-#include "nsswitch.h"
-#include "nsw_passwd.h"
+#include <pwd.h>
 
 extern void print_passwd(struct passwd *);
 
@@ -35,7 +34,7 @@ int main(int argc, char *argv[])
     struct passwd *pw;
 
 
-    pw = nsw_getpwuid(atoi(argv[1]));
+    pw = getpwuid(atoi(argv[1]));
 
     if (pw)
 	print_passwd(pw);
