@@ -33,14 +33,15 @@ main(int argc, char *argv[])
 {
    struct netent *net;
    
-   yp_setnetent(0, NULL);
+   yp_setnetent(0);
 
-   while ((net = yp_getnetent(NULL)))
+   while ((net = yp_getnetent()))
    {
       print_network(net);
    }
     
-   yp_endnetent(NULL);
+   yp_endnetent();
+   
    exit(0);
 }
 
